body, html {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100%;
  font-size: 16px;
  font-family: serif;
}
@media (max-width: 767px) {
  body, html {
    font-size: 12px;
  }
}

.base-container {
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-image: -webkit-gradient(radial, ellipse at center center, 0, ellipse at center center, 100, color-stop(0%, #ffffff), color-stop(100%, #c9c9c9));
  background-image: -webkit-radial-gradient(ellipse at center center, #ffffff, #c9c9c9);
  background-image: -moz-radial-gradient(ellipse at center center, #ffffff, #c9c9c9);
  background-image: -o-radial-gradient(ellipse at center center, #ffffff, #c9c9c9);
  background-image: radial-gradient(ellipse at center center, #ffffff, #c9c9c9);
}
.base-container .center-container {
  display: table;
  width: 100%;
  height: 100%;
}
.base-container .center-container .cell {
  display: table-cell;
  vertical-align: middle;
}
.base-container .center-container .center-block {
  width: 50%;
  margin: 0 auto;
  text-align: center;
  text-shadow: #a0a0a0 2px 2px 3px;
}
.base-container .center-container .center-block h1 {
  display: inline-block;
  position: relative;
  margin: 0;
  padding: 0.1em 0.6em;
}
.base-container .center-container .center-block h1:before {
  content: "\2039";
  top: -0.5em;
  left: -0.1em;
  position: absolute;
  font-size: 1.2em;
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  transform: rotate(45deg);
}
.base-container .center-container .center-block h1:after {
  content: "\203A";
  bottom: -0.5em;
  right: -0.1em;
  position: absolute;
  font-size: 1.2em;
  -webkit-transform: rotate(45deg);
  -moz-transform: rotate(45deg);
  -ms-transform: rotate(45deg);
  -o-transform: rotate(45deg);
  transform: rotate(45deg);
}
