{% extends "skeleton.html" %}

{% block base_content %}
<div class="base-container">
    <div class="center-container">
        <div class="cell">
            <div class="center-block">
                <h1>{{ SITE.name }}</h1>
                <p>{% trans %}Hello World!{% endtrans %}</p>
            </div>
        </div>
    </div>
</div>{% endblock %}