@import "compass/css3";
// 'Horizontal and Vertical centering' trick taken from :
// http://coding.smashingmagazine.com/2013/08/09/absolute-horizontal-vertical-centering-css/
body, html{
    margin: 0;
    padding: 0;
    width: 100%;
    height: 100%;
    font-size: 16px;
    font-family: serif;
    @media (max-width: 767px) {
        font-size: 12px;
    }
}

.base-container{
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    @include background-image(radial-gradient(ellipse at center center, #ffffff, #c9c9c9));
    
    .center-container{
        display: table;
        width: 100%;
        height: 100%;

        .cell{
            display: table-cell;
            vertical-align: middle;
        }
        .center-block{
            width: 50%;
            margin: 0 auto;
            text-align: center;
            @include text-shadow(#a0a0a0 2px 2px 3px);
            
            h1{
                display: inline-block;
                position: relative;
                margin: 0;
                padding: 0.1em 0.6em;
                
                &:before{
                    content: "\2039";
                    top: -0.5em;
                    left: -0.1em;
                    position: absolute;
                    font-size: 1.2em;
                    @include transform(rotate(45deg));
                }
                &:after{
                    content: "\203A";
                    bottom: -0.5em;
                    right: -0.1em;
                    position: absolute;
                    font-size: 1.2em;
                    @include transform(rotate(45deg));
                }
            }
        }
    }
}